==> zio-aws-computeoptimizer_2.12-5.17.203.1-sources.jar: zio/aws/computeoptimizer/model/JobFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters._
final case class JobFilter(
    name: Optional[zio.aws.computeoptimizer.model.JobFilterName] =
      Optional.Absent,
    values: Optional[Iterable[FilterValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.JobFilter = {
    import JobFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.JobFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.computeoptimizer.model.JobFilter.ReadOnly =
    zio.aws.computeoptimizer.model.JobFilter.wrap(buildAwsValue())
}
object JobFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.JobFilter =
      zio.aws.computeoptimizer.model
        .JobFilter(name.map(value => value), values.map(value => value))
    def name: Optional[zio.aws.computeoptimizer.model.JobFilterName]
    def values: Optional[List[FilterValue]]
    def getName
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.JobFilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ) extends zio.aws.computeoptimizer.model.JobFilter.ReadOnly {
    override val name: Optional[zio.aws.computeoptimizer.model.JobFilterName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value => zio.aws.computeoptimizer.model.JobFilterName.wrap(value))
    override val values: Optional[List[FilterValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ): zio.aws.computeoptimizer.model.JobFilter.ReadOnly = new Wrapper(impl)
}

==> zio-aws-computeoptimizer_2.13-5.17.124.1-sources.jar: zio/aws/computeoptimizer/model/JobFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters._
final case class JobFilter(
    name: Option[zio.aws.computeoptimizer.model.JobFilterName] = None,
    values: Option[Iterable[FilterValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.JobFilter = {
    import JobFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.JobFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.computeoptimizer.model.JobFilter.ReadOnly =
    zio.aws.computeoptimizer.model.JobFilter.wrap(buildAwsValue())
}
object JobFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.JobFilter =
      zio.aws.computeoptimizer.model
        .JobFilter(name.map(value => value), values.map(value => value))
    def name: Option[zio.aws.computeoptimizer.model.JobFilterName]
    def values: Option[List[FilterValue]]
    def getName
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.JobFilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ) extends zio.aws.computeoptimizer.model.JobFilter.ReadOnly {
    override val name: Option[zio.aws.computeoptimizer.model.JobFilterName] =
      scala
        .Option(impl.name())
        .map(value => zio.aws.computeoptimizer.model.JobFilterName.wrap(value))
    override val values: Option[List[FilterValue]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.JobFilter
  ): zio.aws.computeoptimizer.model.JobFilter.ReadOnly = new Wrapper(impl)
}
